<?php
/*
Plugin Name:	Avatar on Register for PMPro and BuddyPress
Plugin URI:	https://www.dwdonline.com/uncategorized/wordpress-profile-picture-for-pmpro-buddypress.html to your plugin homepage
Description:	Alows users to upload an avatar / profile picture when registering during the checkout process of Paid Membership Pro and makes it work with BuddyPress.
Version:	1.0
Author:	Philip Deatherage
Author URI:	https://www.dwd.tech
License:	GPL2 etc
License URI:	https://dwd.tech
*/

register_activation_hook( __FILE__, 'dwd_pmp_bp_avatar_on_register_activate' );
function child_plugin_activate(){

    // Require Paid Memberships Pro
    if ( ! is_plugin_active( 'paid-memberships-pro/paid-memberships-pro.php' ) and current_user_can( 'activate_plugins' ) ) {
        // Stop activation redirect and show error
        wp_die('Sorry, but this plugin requires Paid Memberships Pro to be installed and active. <br><a href="' . admin_url( 'plugins.php' ) . '">&laquo; Return to Plugins</a>');
    }
    if ( ! is_plugin_active( 'pmpro-register-helper/pmpro-register-helper.php' ) and current_user_can( 'activate_plugins' ) ) {
        // Stop activation redirect and show error
        wp_die('Sorry, but this plugin requires PMP Register Helper to be installed and active. <br><a href="' . admin_url( 'plugins.php' ) . '">&laquo; Return to Plugins</a>');
    }
}

/*
 * First, let's add the avatar for the WordPress User using Register Helper durinrg the checkout.
 */
function my_updated_user_meta( $meta_id, $user_id, $meta_key, $meta_value ) {
	// Change user_avatar to your Register Helper file upload name.
	if ( 'user_avatar' == $meta_key ) {
		$filename      = $meta_value['fullpath'];
		$filetype      = wp_check_filetype( basename( $filename ), null );
		$wp_upload_dir = wp_upload_dir();
		$attachment    = array(
			'post_mime_type' => $filetype['type'],
			'post_title'     => preg_replace( '/\.[^.]+$/', '', wp_upload_dir() . $filename ),
			'post_status'    => 'inherit',
		);
		$attach_id     = wp_insert_attachment( $attachment, $filename );
		require_once ABSPATH . 'wp-admin/includes/image.php';
		$attach_data = wp_generate_attachment_metadata( $attach_id, $filename );
		wp_update_attachment_metadata( $attach_id, $attach_data );
		update_user_meta( $user_id, 'wp_user_avatar', $attach_id );
	}
}
add_action( 'added_user_meta', 'my_updated_user_meta', 10, 4 );
add_action( 'updated_user_meta', 'my_updated_user_meta', 10, 4 );

function my_user_avatar_filter( $avatar, $id_or_email, $size, $default, $alt ) {
	$my_user = get_userdata( $id_or_email );
	if ( ! empty( $my_user ) ) {
		$avatar_id = get_user_meta( $my_user->ID, 'wp_user_avatar', true );
		if ( ! empty( $avatar_id ) ) {
			$avatar = wp_get_attachment_url( $avatar_id, $size );
			$avatar = "<img alt='{$alt}' src='{$avatar}' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
		}
	}
	return $avatar;
}
add_filter( 'get_avatar', 'my_user_avatar_filter', 20, 5 );

function my_pmprorh_init_avatar() {
	//don't break if Register Helper is not loaded
	if ( ! function_exists( 'pmprorh_add_registration_field' ) ) {
		return false;
	}
	//define the fields
	$fields   = array();
	$fields[] = new PMProRH_Field(
		'user_avatar',              // input name, will also be used as meta key
		'file',                 // type of field
		array(
			'label'     => 'Profile Picture / Avatar',
			'hint'      => 'Recommended size is 500px X 500px',
			'profile'   => true,    // show in user profile
			'addmember' => true,
		)
	);

	//add the fields into a new checkout_boxes are of the checkout page
	foreach ( $fields as $field ) {
		pmprorh_add_registration_field(
			'after_email', // location on checkout page
			$field            // PMProRH_Field object
		);
	}
	//that's it. see the PMPro Register Helper readme for more information and examples.
}
add_action( 'init', 'my_pmprorh_init_avatar' );

//On the PMPro Confirmation, create the BuddyPress avitar.
function my_pmpro_confirmation_message( $message ) {
	
	// First, let's define a few things
	 	$userNickname = get_user_meta( wp_get_current_user()->ID, 'nickname', true );
		$userAvatar = get_user_meta( wp_get_current_user()->ID, 'user_avatar', true );
		$userAvatarFileName = $userAvatar['original_filename'];
		$avatarFileName = pathinfo($userAvatarFileName, PATHINFO_FILENAME);
		$avatarFileNameExtension = pathinfo($userAvatarFileName, PATHINFO_EXTENSION);
		$avatarBasePath = wp_upload_dir()['basedir'];
		$avatarUserID = wp_get_current_user()->ID;
		$fullAvatarPath = $avatarBasePath . '/avatars/' . wp_get_current_user()->ID;
		$pmproAvatar = $avatarBasePath . '/pmpro-register-helper/' . $userNickname . '/' . $avatarFileName . '.' . $avatarFileNameExtension;
		$bpressAvatarFull = $fullAvatarPath . '/' . $avatarUserID . '-' . 'bpfull.' . $avatarFileNameExtension;
		$bpressAvatarThumb = $fullAvatarPath . '/' . $avatarUserID . '-' . 'bpthumb.' . $avatarFileNameExtension;
		
	// Now, let's create the directory for the user in BuddyPress
		if (!file_exists($fullAvatarPath)) {
		    mkdir($fullAvatarPath, 0777, true);
		}
		
	// Now, we copy the files
		copy($pmproAvatar, $bpressAvatarFull);
		copy($pmproAvatar, $bpressAvatarThumb);
		
	// $message = $avatarBasePath . '/pmpro-register-helper/' . $userNickname . '/' . $userAvatarFileName . "File" . $avatarFileName . "." . $avatarFileNameExtension;
	// return $message;
}
add_filter( 'pmpro_confirmation_message', 'my_pmpro_confirmation_message', 10, 1 );

?>